:html_theme.sidebar_secondary.remove:

Release Notes
=============

Version 0.1.4 (released April 17, 2025)
---------------------------------------

* Use consistent log transforms
* Add ruff linter
* Update documentation

**Full Changelog**: https://github.com/reidjohnson/hpipy/compare/v0.1.3...v0.1.4

Version 0.1.3 (released April 16, 2025)
---------------------------------------

* Fix mypy errors
* Update build process
* Update documentation

**Full Changelog**: https://github.com/reidjohnson/hpipy/compare/v0.1.2...v0.1.3

Version 0.1.2 (released April 15, 2025)
---------------------------------------

* Fix build issues
* Add dataset loader

**Full Changelog**: https://github.com/reidjohnson/hpipy/compare/v0.1.1...v0.1.2

Version 0.1.1 (released April 14, 2025)
---------------------------------------

* Fix manifest file
* Update documentation

**Full Changelog**: https://github.com/reidjohnson/hpipy/compare/v0.1.0...v0.1.1

Version 0.1.0 (released April 12, 2025)
---------------------------------------

* First release on PyPI
